@@ -1,6 +1,6 @@
 package Pithub;
 {
-  $Pithub::VERSION = '0.01013';
+  $Pithub::VERSION = '0.01014';
 }
 
 # ABSTRACT: Github v3 API
@@ -69,7 +69,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01013
+version 0.01014
 
 =head1 SYNOPSIS
 
@@ -309,6 +309,16 @@ See also: L<http://developer.github.com/v3/issues/>
 
 =item *
 
+L<Pithub::Issues::Assignees>
+
+See also: L<http://developer.github.com/v3/issues/assignees/>
+
+    my $assignees = Pithub->new->issues->assignees;
+    my $assignees = Pithub::Issues->new->assignees;
+    my $assignees = Pithub::Issues::Assignees->new;
+
+=item *
+
 L<Pithub::Issues::Comments>
 
 See also: L<http://developer.github.com/v3/issues/comments/>
@@ -450,6 +460,16 @@ See also: L<http://developer.github.com/v3/repos/commits/>
 
 =item *
 
+L<Pithub::Repos::Contents>
+
+See also: L<http://developer.github.com/v3/repos/contents/>
+
+    my $contents = Pithub->new->repos->contents;
+    my $contents = Pithub::Repos->new->contents;
+    my $contents = Pithub::Repos::Contents->new;
+
+=item *
+
 L<Pithub::Repos::Downloads>
 
 See also: L<http://developer.github.com/v3/repos/downloads/>
@@ -539,6 +559,8 @@ See also: L<http://developer.github.com/v3/users/keys/>
 
 =back
 
+=back
+
 =head1 AUTHOR
 
 Johannes Plunien <plu@cpan.org>
