@@ -1,6 +1,6 @@
 package Pithub::Repos;
 {
-  $Pithub::Repos::VERSION = '0.01013';
+  $Pithub::Repos::VERSION = '0.01014';
 }
 
 # ABSTRACT: Github v3 Repos API
@@ -9,6 +9,7 @@ use Moo;
 use Carp qw(croak);
 use Pithub::Repos::Collaborators;
 use Pithub::Repos::Commits;
+use Pithub::Repos::Contents;
 use Pithub::Repos::Downloads;
 use Pithub::Repos::Forks;
 use Pithub::Repos::Hooks;
@@ -38,6 +39,11 @@ sub commits {
 }
 
 
+sub contents {
+    return shift->_create_instance('Pithub::Repos::Contents');
+}
+
+
 sub contributors {
     my ( $self, %args ) = @_;
     $self->_validate_user_repo_args( \%args );
@@ -186,7 +192,7 @@ Pithub::Repos - Github v3 Repos API
 
 =head1 VERSION
 
-version 0.01013
+version 0.01014
 
 =head1 METHODS
 
@@ -215,6 +221,10 @@ Provides access to L<Pithub::Repos::Collaborators>.
 
 Provides access to L<Pithub::Repos::Commits>.
 
+=head2 contents
+
+Provides access to L<Pithub::Repos::Contents>.
+
 =head2 contributors
 
 =over
